============
Contributing
============

Contributions are welcome.

Submit contributions as a pull request on GitHub.


Standards
---------
- All contributions must be PEP complaint.
- All modules, classes, and functions must have Sphinx style doc strings.
- All parameters and variables should have type annotations.
- A reasonable amount of code block documentation is expected as well.
